<?php
include("_dirinfo.php");
include(PATH_TO_ROOT . "_config/dbConfig.php");

$config = configLoader::loadConfig('update_script');

define("SHOW_LOG_MESSAGES", $config['show_log_messages']);

$verzija = $db->get('_WarpitConfig', 'cName = "version"', 'cValue', DB_WARPIT_MAIN);
$verzija = $verzija[0];
$db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
$sql = "SELECT proj_name,id FROM _Projects";
$res = $db->SQLexecute($sql);
if (SHOW_LOG_MESSAGES) {
    var_dump($db->NumRows($res));
}

//$db->ChangeDatabase(DB_WARPIT_WEBCATI);

while ($row = $db->fetchRow($res)) {

    $tbl = $row[0];
    $projId = $row[1];

    try {
        if (1 > $verzija) {
            /*$sql = "ALTER TABLE  `$tbl"."_structure` ADD  d_stop DATETIME AFTER t_stop,ADD d_start DATETIME AFTER t_stop,ADD d_status DATETIME AFTER t_stop";
            //$db->SQLexecute($sql);

            $sql = "UPDATE $tbl"."_structure SET d_stop = FROM_UNIXTIME(t_stop),d_start = FROM_UNIXTIME(t_start)";
            $db->SQLexecute($sql);

            $sql = "ALTER TABLE  `$tbl"."___telIndex` ADD  ank_user_type TINYINT AFTER id_ank";
            $db->SQLexecute($sql);

            $sql = "ALTER TABLE  `$tbl"."_structure` ADD  user_type TINYINT AFTER user_id";
            $db->SQLexecute($sql);
            $sql = "ALTER TABLE  `".$tbl."___telLog` ADD  user_type TINYINT AFTER id_user";;
            $db->SQLexecute($sql);*/
            $db->ChangeDatabase(DB_WARPIT_WEBCATI);

            /*	$sql = "ALTER TABLE  `".$tbl."` DROP  attachAnswers";
                $db->SQLexecute($sql);

                $sql = "ALTER TABLE  `".$tbl."` ADD  attachAnswers int(11) AFTER anno_sql";;
                $db->SQLexecute($sql);

                $sql = "ALTER TABLE  `".$tbl."` ADD  attachFalse BOOL AFTER attachAnswers";;
                $db->SQLexecute($sql);
                */
            $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);

            /*$sql = "ALTER TABLE  `".$tbl."___EngineLog` ADD  eventLogger text";;
            $db->SQLexecute($sql);*/

            $db->ChangeDatabase(DB_WARPIT_WEBCATI);
            /*$sql = "ALTER TABLE  `".$tbl."` ADD  srotAttributes int(1), ADD erotAttributes int(1)";
            $db->SQLexecute($sql);
            */
            $sql = "ALTER TABLE  `" . $tbl . "` ADD  open_attributes char(250) NULL, ADD filter_attributes text NULL";
            $db->SQLexecute($sql);

        }
        if (4 > $verzija) {
            $db->ChangeDatabase(DB_WARPIT_WEBCATI);
            $sql = "ALTER TABLE `" . $tbl . "` ADD answerGroups text NULL,ADD legendGroups text NULL";
            $db->SQLexecute($sql);

            $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
            $sql = "ALTER TABLE `" . $tbl . "_structure` ADD id_device tinyint AFTER user_cp";
            $db->SQLexecute($sql);
        }
        if (5 > $verzija) {
            $db->ChangeDatabase(DB_WARPIT_WEBCATI);
            $sql = "UPDATE $tbl SET goto_sql='\$status==1#-6,\$status==90#-8,true#-10' WHERE q_pos = -9";
            $db->SQLexecute($sql);
        }
        if (7 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "_structure ADD id_telname INT(8) AFTER id_tel";
                $db->SQLexecute($sql);
                $sql = "ALTER TABLE " . $tbl . "___telLog ADD id_telname INT(8) AFTER id_tel";
                $db->SQLexecute($sql);
            } catch (Exception $e) {

            }
            $sql = "ALTER TABLE " . $tbl . "___EngineLog ADD id_user int(11) NOT NULL, ADD user_type tinyint(4) NOT NULL";
            $db->SQLexecute($sql);
        }
        if (9 > $verzija) {
            $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
            $length = 15;
            $characters = "0123456789abcdefghijklmnopqrstuvwxyz";
            $charCnt = strlen($characters) - 1;
            $string = '';
            for ($p = 0; $p < $length; $p++) {
                $string .= $characters[mt_rand(0, $charCnt)];
            }
            $sqlTmp = "INSERT INTO _www_externalLinks (`id_project`, `linkType`, `loginSID`) VALUES ($projId,1,'" . $string . "-')";
            $db->SQLexecute($sqlTmp);
            $wwwId = $db->GetLastInsertId();
            $sqlTmp = "UPDATE _www_externalLinks SET loginSID = CONCAT(loginSID,id) WHERE id = $wwwId";
            $db->SQLexecute($sqlTmp);

            $string = '';
            for ($p = 0; $p < $length; $p++) {
                $string .= $characters[mt_rand(0, $charCnt)];
            }
            $sqlTmp = "INSERT INTO _www_externalLinks (`id_project`, `linkType`, `loginSID`) VALUES ($projId,2,'" . $string . "-')";
            $db->SQLexecute($sqlTmp);
            $wwwId = $db->GetLastInsertId();
            $sqlTmp = "UPDATE _www_externalLinks SET loginSID = CONCAT(loginSID,id) WHERE id = $wwwId";
            $db->SQLexecute($sqlTmp);

            $string = '';
            for ($p = 0; $p < $length; $p++) {
                $string .= $characters[mt_rand(0, $charCnt)];
            }
            $sqlTmp = "INSERT INTO _www_externalLinks (`id_project`, `linkType`, `loginSID`) VALUES ($projId,3,'" . $string . "-')";
            $db->SQLexecute($sqlTmp);
            $wwwId = $db->GetLastInsertId();
            $sqlTmp = "UPDATE _www_externalLinks SET loginSID = CONCAT(loginSID,id) WHERE id = $wwwId";
            $db->SQLexecute($sqlTmp);

        }
        if (13 > $verzija) {

            $lng = $db->get('_Projects', $projId, 'language', DB_WARPIT_WEBCATI_BASE);
            $db->ChangeDatabase(DB_WARPIT_WEBCATI);


            $sql = "INSERT INTO $tbl (q_pos,q_name,tip_sql) VALUES (-16,'_notActive',5)";
            $db->SQLexecute($sql);

            $lastId = $db->GetLastInsertId();
            $sql = "INSERT INTO $tbl" . "_language (id_language,id_question,id_text_type,lngText) VALUES ($lng, $lastId,2,'This survey is not active!')";
            $db->SQLexecute($sql);

            //povecat ID od dreve za jedno!
            $treeAI = $db->getAutoIncVal($tbl . '_tree');
            $treeAI++;
            $db->SQLexecute("ALTER TABLE $tbl" . "_tree AUTO_INCREMENT = $treeAI");

        }
        if (19 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "___telIndex ADD `status_comment` varchar(250) COLLATE utf8_unicode_ci NOT NULL AFTER app_koment";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telIndex can not be modified!</font><br>";
                }
            }
        }
        if (30 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " CHANGE `answers_filter` `answers_filter` TINYINT( 1 ) NOT NULL DEFAULT '0'";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    echo "Field answers_filter does not exist...!";
                }
            }
        }
        if (34 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `repeat_legend` INT NOT NULL";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified!</font><br>";
                }
            }
        }
        if (35 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "___quotaCalc ADD `QT_user_type` INT NOT NULL AFTER `QT_user_id`";
                $db->SQLexecute($sql);


            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___quotaCalc can not be modified!</font><br>";
                }
            }
        }
        if (43 > $verzija) {
            // add id_mask...
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `id_mask` INT(8) NULL AFTER `id_style`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with id_mask!</font><br>";
                }
            }

            // structure add index on id_tel
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "_structure ADD KEY `id_tel` (`id_tel`)";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "_structure can not be modified with INDEX on id_tel!</font><br>";
                }
            }

            // structure add index on id_telname
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "_structure ADD KEY `id_telname` (`id_telname`)";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "_structure can not be modified with INDEX on id_telname!</font><br>";
                }
            }

        }
        if (53 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "_structure CHANGE `user_cp` `id_loginSID` INT NULL DEFAULT NULL";
                $db->SQLexecute($sql);


            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "_structure can not be modified!</font><br>";
                }
            }
        }
        if (55 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `" . $tbl . "___telLog`
						ADD `int_channel_id` varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
						ADD `int_channel` varchar(100) COLLATE utf8_unicode_ci DEFAULT NULL,
						ADD `ext_channel_id` varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
						ADD `ext_channel` varchar(100) COLLATE utf8_unicode_ci DEFAULT NULL,
						ADD `sip` varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
						ADD KEY `int_channel_id` (`int_channel_id`),
						ADD KEY `ext_channel_id` (`ext_channel_id`)";
                $db->SQLexecute($sql);


            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telLog can not be modified with Asterisk components!</font><br>";
                }
            }
        }
        if (61 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "___telIndex ADD `callback` tinyint NOT NULL DEFAULT 0 AFTER call_num";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telIndex can not be modified!</font><br>";
                }
            }
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE " . $tbl . "___telIndex ADD INDEX `callback` (`callback`)";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telIndex can not be modified with INDEX on callback!</font><br>";
                }
            }
        }
        if (63 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `autoSubmit` tinyint(1) NOT NULL default 0";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with autoSubmit feature!</font><br>";
                }
            }
        }
        if (77 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `multi_nogo_legends` VARCHAR( 100 ) NOT NULL AFTER `multi_nogo_answers`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with no-go for legend feature!</font><br>";
                }
            }
        }
        if (78 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `id_plugin` int(5) NULL";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with plugin feature!</font><br>";
                }
            }
        }
        if (80 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `missing_values` VARCHAR( 100 ) NULL";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with missing values feature!</font><br>";
                }

            }
        }
        if (82 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `id_incentive` INT( 11 ) NULL";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with id_incentive!</font><br>";
                }
            }
        }

        if (83 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `incentive_possibilites` TINYINT( 1 ) NOT NULL DEFAULT  '0'";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with id_incentive!</font><br>";
                }
            }
        }
        if (83 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD `allow_listening` TINYINT( 1 ) NOT NULL DEFAULT  '0' AFTER  `incentive_possibilites`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with allow_listening!</font><br>";
                }
            }
        }
        if (106 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `" . $tbl . "___EngineLog` ADD `id_language` SMALLINT NULL AFTER `user_type`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___EngineLog can not be modified with id_language!</font><br>";
                }
            }
        }
        if (112 > $verzija) {
            try {

                /*$sql = "SELECT proj_name FROM ".DB_WARPIT_WEBCATI_BASE."._Projects";
                if(!$res = $db->SQLexecute($sql)) die($db->JsonError());
                while($row = $db->fetchRow($res)){

                    if($db->TableExists($row[0], DB_WARPIT_WEBCATI)){
                        $sql = "SHOW COLUMNS FROM ".DB_WARPIT_WEBCATI.".".$row[0]." LIKE 'open_end_type'";
                        if(!$temp = $db->SQLexecute($sql)) die($db->JsonError());
                        if($db->NumRows($temp) == 0){
                            $sql = "ALTER TABLE `".DB_WARPIT_WEBCATI."`.`".$row[0]."` ADD `open_end_type` TINYINT ( 4) NOT NULL DEFAULT '1' COMMENT '1 text box 2 text area'";
                            if(!$db->SQLexecute($sql)) die($db->JsonError());
                        }
                    }
                }*/
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . DB_WARPIT_WEBCATI . "`.`" . $tbl . "` ADD `open_end_type` TINYINT ( 4) NOT NULL DEFAULT '1' COMMENT '1 text box 2 text area'";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with open_end_type!</font><br>";
                }
            }
        }
        if (130 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                //$sql = "ALTER TABLE `".$tbl.` ADD `id_language` SMALLINT NULL AFTER `user_type`";
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `enter_submit` TINYINT(1) NOT NULL DEFAULT '1' AFTER `open_end_type`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with enter_submit!</font><br>";
                }
            }
        }
        if (133 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `slider_color` VARCHAR(10) NULL, ADD COLUMN `trace_color` VARCHAR(10) NULL, ADD COLUMN `slider_shape` VARCHAR(50) NULL";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with slider_color, trace_color, slider_shape columns!</font><br>";
                }
            }

        }
        if (133 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `slider_handle_image` VARCHAR(255) NULL";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with slider handle image</font><br>";
                }
            }

        }
        if (134 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `email_app_group` INT NULL, ADD COLUMN `email_app_template` INT NULL";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with email_app_group and email_app_template</font><br>";
                }
            }

        }

        if (134 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                //ALTER TABLE `appcommentproblem___telLog` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci' AFTER `end_time`;
                $sql = "ALTER TABLE `" . $tbl . "___telLog` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci'";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telLog can not be modified varchar(250) -> text</font><br>";
                }
            }

            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                //ALTER TABLE `appcommentproblem___telIndex` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci' AFTER `app_time`;
                $sql = "ALTER TABLE `" . $tbl . "___telIndex` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci'";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___telIndex can not be modified: varchar(250) -> text</font><br>";
                }
            }

        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `" . $tbl . "___quotaLimits` ADD COLUMN `enabled` TINYINT(1) NOT NULL DEFAULT '1'";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___quotaLimits can not be modified: add enabled TINYINT(1) NOT NULL DEFAULT '1'<br>";
                }
            }

        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                //ALTER TABLE `encrypt` ADD COLUMN `encrypt` TINYINT(1) NULL DEFAULT NULL AFTER `email_app_template`;
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `encrypt` TINYINT(1) NULL DEFAULT NULL";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add encrypt<br>";
                }
            }

        }

        if (141 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                //ALTER TABLE `appcommentproblem___telLog` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci' AFTER `end_time`;
                //	$sql = "ALTER TABLE `" . $tbl . "___telLog` CHANGE COLUMN `app_koment` `app_koment` TEXT NULL DEFAULT NULL COLLATE 'utf8_unicode_ci'";
                $sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `multi_type` TINYINT(4) NULL DEFAULT '1' COMMENT '1 column multi response 2 line multi response 3 line and column'";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add multi_type column</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
$sql = "INSERT INTO `" . $tbl . "` (`q_pos`, `q_name`, `tip_sql`, `disable_question`) VALUES (-3, '_Repeal', 5, 1);";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: inserted repeal question</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
//							$sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `multi_type` TINYINT(4) NULL DEFAULT '1' COMMENT '1 column multi response 2 line multi response 3 line and column'";
                $sql = "ALTER TABLE `" . $tbl . "`
											ADD COLUMN `rotate_legend` TINYINT(4) UNSIGNED NOT NULL DEFAULT '0' COMMENT '0 do not rotate legend text 1 rotate legend on desktop 2 rotate legend on mobile 3 rotate legend on both' AFTER `multi_type`";
                $db->SQLexecute($sql);

            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add rotate_legend column</font><br>";
                }
            }
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                //							$sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `multi_type` TINYINT(4) NULL DEFAULT '1' COMMENT '1 column multi response 2 line multi response 3 line and column'";
                $sql = "ALTER TABLE `" . $tbl . "`
											ADD COLUMN `custom_controls` TEXT NULL AFTER `rotate_legend`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add custom_controls column</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
//							$sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `multi_type` TINYINT(4) NULL DEFAULT '1' COMMENT '1 column multi response 2 line multi response 3 line and column'";
                $sql = "ALTER TABLE `" . $tbl . "`
										ADD COLUMN `rec_question_id` INT NULL DEFAULT '0' AFTER `custom_controls`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add custom_controls column</font><br>";
                }
            }
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
//							$sql = "ALTER TABLE `" . $tbl . "` ADD COLUMN `multi_type` TINYINT(4) NULL DEFAULT '1' COMMENT '1 column multi response 2 line multi response 3 line and column'";
                $sql = "ALTER TABLE `" . $tbl . "___EngineLog`
	                               ADD COLUMN `activeRecord` TINYINT(1) NOT NULL AFTER `eventLogger`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___EngineLog can not be modified: add coluumn active record</font><br>";
                }
            }
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE " . $tbl . " ADD COLUMN `rec_interval` VARCHAR(50) NULL DEFAULT NULL COMMENT 'start_q:end_q' AFTER `rec_question_id`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add coluumn active record and index on id_user-user_type</font><br>";
                }
            }
        }

        if (SHOW_LOG_MESSAGES) {
            echo "$tbl SUCCESSFUL!<br>";
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}` ADD COLUMN `anonymize` TINYINT NOT NULL DEFAULT '0' AFTER `rotate_legend`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add anonymize flag</font><br>";
                }
            }
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}___EngineLog` ADD INDEX `id_user_user_type_activeRecord` (`id_user`, `user_type`, `activeRecord`);";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add id_user_user_type_activeRecord index on EngineLog</font><br>";
                }
            }
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}___EngineLog` DROP INDEX `id_user_user_type`";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: drop id_user_user_type on EngineLog</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}`
	                      ADD COLUMN `input_types` VARCHAR(255) NULL AFTER `anonymize`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with input_types column!</font><br>";
                }
            }
        }

        if (SHOW_LOG_MESSAGES) {
            echo "$tbl SUCCESSFUL!<br>";
        }
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}_structure`
                                ADD INDEX `id_tel` (`id_tel`),
                                ADD INDEX `id_telname` (`id_telname`)";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " cannot add id_tel and id_telname index</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}___EngineLog`
                            ADD COLUMN `browser_type_id` SMALLINT(6) NOT NULL AFTER `activeRecord`,
                            ADD COLUMN `device_name_id` SMALLINT(6) NOT NULL AFTER `browser_type_id`,
                            ADD COLUMN `device_property_id` SMALLINT(6) NOT NULL AFTER `device_name_id`,
                            ADD INDEX `browser_type_id` (`browser_type_id`),
                            ADD INDEX `device_name_id` (`device_name_id`),
                            ADD INDEX `device_property_id` (`device_property_id`)";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___EngineLog cannot add browser info fields</font><br>";
                }
            }
        }

        if (SHOW_LOG_MESSAGES) {
            echo "$tbl SUCCESSFUL!<br>";
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                      ADD COLUMN `autoSubmitTimeout` INT NOT NULL DEFAULT '100' AFTER `autoSubmit`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with autoSubmitTimeout column!</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                      ADD COLUMN `input_types_properties` TEXT NULL AFTER `input_types`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with input_types_properties column!</font><br>";
                }
            }
        }

        if(142 > $verzija)
        {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl . "`
								ADD COLUMN `show_as_single` TINYINT NOT NULL DEFAULT '0' AFTER `rec_interval`,
								ADD COLUMN `show_as_single_cond` TEXT NULL AFTER `show_as_single`,
								ADD COLUMN `show_as_single_title` VARCHAR(255) NULL AFTER `show_as_single_cond`,
								ADD COLUMN `show_as_single_odd` VARCHAR(255) NULL AFTER `show_as_single_title`,
								ADD COLUMN `show_as_single_even` VARCHAR(255) NULL AFTER `show_as_single_odd`,
								ADD COLUMN `show_as_single_autosubmit` TINYINT(1) NULL DEFAULT '0' AFTER `show_as_single_even`,
								ADD COLUMN `show_as_single_autosubmit_delay` INT NULL DEFAULT '200' AFTER `show_as_single_autosubmit`,
								ADD COLUMN `show_as_single_error_message` VARCHAR(255) NULL AFTER `show_as_single_autosubmit_delay`
								";

                $db->SQLexecute($sql);
            } catch (Exception $e)
            {
                if(SHOW_LOG_MESSAGES)
                {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table ".$tbl." can not be modified: add properties for scale as single</font><br>";
                }
            }
        }

        if(142 > $verzija)
        {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl ."`
                            ADD COLUMN `show_as_single_design` INT NULL AFTER `show_as_single_cond`,
                            DROP COLUMN `show_as_single_title`,
                            DROP COLUMN `show_as_single_odd`,
                            DROP COLUMN `show_as_single_even`,
                            DROP COLUMN `show_as_single_error_message`";

                $db->SQLexecute($sql);
            } catch (Exception $e)
            {
                if(SHOW_LOG_MESSAGES)
                {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table ".$tbl." can not be modified: add properties for scale as single</font><br>";
                }
            }
        }

        if(142 > $verzija)
        {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `" . $tbl ."`
	                      ADD INDEX `show_as_single_design` (`show_as_single_design`)";

                $db->SQLexecute($sql);
            } catch (Exception $e)
            {
                if(SHOW_LOG_MESSAGES)
                {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table ".$tbl." can not be modified: add index on show as single</font><br>";
                }
            }
        }

        if(142 > $verzija)
        {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
                          ADD COLUMN `input_position` TINYINT NOT NULL DEFAULT '1' COMMENT '1 next to label 2 under label' AFTER `show_as_single_autosubmit_delay`";

                $db->SQLexecute($sql);
            } catch (Exception $e)
            {
                if(SHOW_LOG_MESSAGES)
                {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table ".$tbl." can not be modified: add input_position field</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                      ADD COLUMN `after_text` VARCHAR(255) NULL AFTER `input_position`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with after_text column!</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                      ADD COLUMN `autoSubmitTimeout` INT NOT NULL DEFAULT '100' AFTER `autoSubmit`";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with autoSubmitTimeout column!</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                        ADD COLUMN `answer_click_animation` VARCHAR(50) NOT NULL DEFAULT '0' COLLATE 'utf8_unicode_ci'";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with answer_click_animation column!</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                        ADD COLUMN `answer_click_element` INT NULL DEFAULT NULL COMMENT '1 - control 2 - label 3 both'";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with answer_click_element column!</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
                $sql = "ALTER TABLE `{$tbl}`
	                        ADD COLUMN `answer_click_animation_duration` INT NOT NULL DEFAULT 1000";
                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified with answer_click_animation column!</font><br>";
                }
            }
        }

        if (SHOW_LOG_MESSAGES) {
            echo "$tbl SUCCESSFUL!<br>";
        }
    } catch (Exception $e) {
        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `{$tbl}___EngineLog` ADD INDEX `id_user_user_type_activeRecord` (`id_user`, `user_type`, `activeRecord`);";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add id_user_user_type_activeRecord index on EngineLog</font><br>";
                }
            }
        }

        if (142 > $verzija) {
            try {
                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                $sql = "ALTER TABLE `" . $tbl . "___EngineLog`
	                               ADD INDEX `id_user_user_type` (`id_user`, `user_type`)";

                $db->SQLexecute($sql);
            } catch (Exception $e) {
                if (SHOW_LOG_MESSAGES) {
                    var_dump($e->getMessage());
                    echo "<br><font color=red>Table " . $tbl . "___EngineLog can not be modified: index on id_user-user_type</font><br>";
                }
            }
        }

        if (SHOW_LOG_MESSAGES) {
            echo "$tbl SUCCESSFUL!<br>";
        }
    }
    catch (Exception $e) {
        if (SHOW_LOG_MESSAGES) {
            print_r($e->getMessage());
            echo "<br><br><br>";
        }
    }

}
?>
